@@ -27,38 +27,40 @@ var AdminFilters = function(element, labels, form, filters, active_filters) {
     {
         var $el = $('<tr />').appendTo($container);
 
-	addRemoveFilter($el, name, labels[name]);
+	    addRemoveFilter($el, name, labels[name]);
         var i_option = addFilterOptionsValue($el, name, filter_name);
 	
-        var $field = $(form[name])
+        var $field = $(form[name]);
         // if form item complex like <div><input bla></div>, datetime
         if ( $("input", $($field)).html() != undefined ) {
-		$field_inner = $("input", $field)
-		$field_inner.attr('name', '_flt_' + i_option + '_' + name);
-		$field_inner.val(value);
-		$field_inner.attr('class', ' filter_val ' + $field_inner.attr('class'));
-	}
-	else {
-		$field.attr('name', '_flt_' + i_option + '_' + name);	
-		$field.val(value);
-        	$field.attr('class', ' filter_val ' + $field.attr('class'));
-	
-	}
+            $field_inner = $("input", $field)
+            $field_inner.attr('name', '_flt_' + i_option + '_' + name);
+            $field_inner.val(value);
+            $field_inner.attr('class', ' filter_val ' + $field_inner.attr('class'));
+	    }
+        else {
+            if (($field.attr( 'type')) == 'checkbox') {
+                $field.attr( 'checked', true );
+            }
+            $field.attr('name', '_flt_' + i_option + '_' + name);
+            $field.val(value);
+            $field.attr('class', ' filter_val ' + $field.attr('class'));
+        }
         $el.append(
-        	$('<td/>').append($field)
-        );;
+            $('<td/>').append($field)
+            );
     }
 
 	function addRemoveFilter($el, name, label)
 	{
 		$el.append(
-                $('<td class="col-lg-1 col-md-1" />').append(
-                    $('<a href="#" class="btn remove-filter" />')
-                        .append($('<span class="close-icon">&times;</span>'))
-                        .append('&nbsp;')
-                        .append(label)
-                        .click(removeFilter)
-                    )
+            $('<td class="col-lg-1 col-md-1" />').append(
+                $('<a href="#" class="btn remove-filter" />')
+                    .append($('<span class="close-icon">&times;</span>'))
+                    .append('&nbsp;')
+                    .append(label)
+                    .on('click', removeFilter)
+                )
             );
 	}
 
@@ -84,7 +86,7 @@ var AdminFilters = function(element, labels, form, filters, active_filters) {
         );
         // avoids error
         if (i_option == -1) { $select.select2(); }
-        $select.change(function(e) {
+        $select.on('change', function(e) {
         	changeOperation(e, $el, name)
     	});
         
@@ -95,25 +97,25 @@ var AdminFilters = function(element, labels, form, filters, active_filters) {
     function addFilter(name, filter) {
         var $el = $('<tr />').appendTo($container);
 		
-	addRemoveFilter($el, name, labels[name]);
+	    addRemoveFilter($el, name, labels[name]);
 
         addFilterOptionsValue($el, name);
-	var $field = $(form[name])
+	    var $field = $(form[name]);
 	
-	// if form item complex like <div><input bla></div>, datetime
-	if ( $("input", $($field)).html() != undefined ) {
-		$field_inner = $("input", $($field))
-		$field_inner.attr('name', '_flt_0_' + name);
-		$field_inner.attr('class', ' filter_val ' + $field_inner.attr('class'));
+	    // if form item complex like <div><input bla></div>, datetime
+	    if ( $("input", $($field)).html() != undefined ) {
+		    $field_inner = $("input", $($field))
+		    $field_inner.attr('name', '_flt_0_' + name);
+		    $field_inner.attr('class', ' filter_val ' + $field_inner.attr('class'));
 	
-	}
-	else {
-		$field.attr('name', '_flt_0_' + name);
-		$field.attr('class', ' filter_val ' + $field.attr('class'));
-	}
-	$el.append(
+	    }
+	    else {
+		    $field.attr('name', '_flt_0_' + name);
+		    $field.attr('class', ' filter_val ' + $field.attr('class'));
+	    }
+	    $el.append(
         	$('<td/>').append($field)
-        );;
+        );
         if ($field.hasClass( "my_select2" )) {
         	$field.select2({placeholder: "Select a State", allowClear: true});
         }
@@ -124,7 +126,7 @@ var AdminFilters = function(element, labels, form, filters, active_filters) {
         	$field.datetimepicker({pickTime: false });
         }
         lastCount += 1;
-    };
+    }
 
 	// ----------------------------------------------------------
 	// Trigger for option change will change input element name
@@ -135,8 +137,8 @@ var AdminFilters = function(element, labels, form, filters, active_filters) {
     }
 
 
-    $('a.filter').click(function() {
-        var name = $(this).attr('name')
+    $('a.filter').on('click', function() {
+        var name = $(this).attr('name');
         addFilter(name);
     });
     
